@@ -7,7 +7,7 @@ module Asana
     module EventSubscription
       # Public: Returns an infinite collection of events on the resource.
       def events(wait: 1, options: {})
-        Events.new(resource: id, client: client, wait: wait, options: options)
+        Events.new(resource: gid, client: client, wait: wait, options: options)
       end
     end
   end
